summaryrefslogtreecommitdiff
path: root/framework/Web/UI/WebControls/TImageButton.php
diff options
context:
space:
mode:
authorxue <>2006-01-21 17:29:40 +0000
committerxue <>2006-01-21 17:29:40 +0000
commit3fcf847e0cadfb9ede930f538c2f277483442175 (patch)
tree12534cf4b29c1d4676fd59ab47adb60e292bcb6c /framework/Web/UI/WebControls/TImageButton.php
parent99b56c855a597c606d349c7063d843539e65a6ed (diff)
BE AWARE: Significant change!
Changed event definition from XXX to OnXXX.
Diffstat (limited to 'framework/Web/UI/WebControls/TImageButton.php')
-rw-r--r--framework/Web/UI/WebControls/TImageButton.php24
1 files changed, 12 insertions, 12 deletions
diff --git a/framework/Web/UI/WebControls/TImageButton.php b/framework/Web/UI/WebControls/TImageButton.php
index 7674cf56..dfa1752c 100644
--- a/framework/Web/UI/WebControls/TImageButton.php
+++ b/framework/Web/UI/WebControls/TImageButton.php
@@ -27,7 +27,7 @@ Prado::using('System.Web.UI.WebControls.TImage');
* associated with the button. This allows you to create multiple TLinkButton
* components on a Web page and programmatically determine which one is clicked
* with what parameter. You can provide an event handler for
- * {@link onCommand Command} event to programmatically control the actions performed
+ * {@link onCommand OnCommand} event to programmatically control the actions performed
* when the command button is clicked. In the event handler, you can determine
* the {@link setCommandName CommandName} property value and
* the {@link setCommandParameter CommandParameter} property value
@@ -38,9 +38,9 @@ Prado::using('System.Web.UI.WebControls.TImage');
* A <b>submit</b> button does not have a command name associated with the button
* and clicking on it simply posts the Web page back to the server.
* By default, a TImageButton control is a submit button.
- * You can provide an event handler for the {@link onClick Click} event
+ * You can provide an event handler for the {@link onClick OnClick} event
* to programmatically control the actions performed when the submit button is clicked.
- * The coordinates of the clicking point can be obtained from the {@link onClick Click}
+ * The coordinates of the clicking point can be obtained from the {@link onClick OnClick}
* event parameter, which is of type {@link TImageClickEventParameter}.
*
* Clicking on button can trigger form validation, if
@@ -147,26 +147,26 @@ class TImageButton extends TImage implements IPostBackDataHandler, IPostBackEven
/**
* This method is invoked when the button is clicked.
* The method raises 'Click' event to fire up the event handlers.
* If you override this method, be sure to call the parent implementation
* so that the event handler can be invoked.
* @param TImageClickEventParameter event parameter to be passed to the event handlers
*/
public function onClick($param)
{
- $this->raiseEvent('Click',$this,$param);
+ $this->raiseEvent('OnClick',$this,$param);
}
/**
* This method is invoked when the button is clicked.
* The method raises 'Command' event to fire up the event handlers.
* If you override this method, be sure to call the parent implementation
* so that the event handlers can be invoked.
* @param TCommandEventParameter event parameter to be passed to the event handlers
*/
public function onCommand($param)
{
- $this->raiseEvent('Command',$this,$param);
+ $this->raiseEvent('OnCommand',$this,$param);
$this->raiseBubbleEvent($this,$param);
}
@@ -175,7 +175,7 @@ class TImageButton extends TImage implements IPostBackDataHandler, IPostBackEven
* This method is required by {@link IPostBackEventHandler} interface.
* If {@link getCausesValidation CausesValidation} is true, it will
* invoke the page's {@link TPage::validate validate} method first.
- * It will raise {@link onClick Click} and {@link onCommand Command} events.
+ * It will raise {@link onClick OnClick} and {@link onCommand OnCommand} events.
* This method is mainly used by framework and control developers.
* @param TEventParameter the event parameter
*/
@@ -204,7 +204,7 @@ class TImageButton extends TImage implements IPostBackDataHandler, IPostBackEven
}
/**
- * @return string the command name associated with the {@link onCommand Command} event.
+ * @return string the command name associated with the {@link onCommand OnCommand} event.
*/
public function getCommandName()
{
@@ -212,7 +212,7 @@ class TImageButton extends TImage implements IPostBackDataHandler, IPostBackEven
}
/**
- * Sets the command name associated with the {@link onCommand Command} event.
+ * Sets the command name associated with the {@link onCommand OnCommand} event.
* @param string the text caption to be set
*/
public function setCommandName($value)
@@ -221,7 +221,7 @@ class TImageButton extends TImage implements IPostBackDataHandler, IPostBackEven
}
/**
- * @return string the parameter associated with the {@link onCommand Command} event
+ * @return string the parameter associated with the {@link onCommand OnCommand} event
*/
public function getCommandParameter()
{
@@ -229,7 +229,7 @@ class TImageButton extends TImage implements IPostBackDataHandler, IPostBackEven
}
/**
- * Sets the parameter associated with the {@link onCommand Command} event.
+ * Sets the parameter associated with the {@link onCommand OnCommand} event.
* @param string the text caption to be set
*/
public function setCommandParameter($value)
@@ -147,26 +147,26 @@ class TImageButton extends TImage implements IPostBackDataHandler, IPostBackEven
/**
* This method is invoked when the button is clicked.
- * The method raises 'Click' event to fire up the event handlers.
+ * The method raises 'OnClick' event to fire up the event handlers.
* If you override this method, be sure to call the parent implementation
* so that the event handler can be invoked.
@@ -147,26 +147,26 @@ class TImageButton extends TImage implements IPostBackDataHandler, IPostBackEven
/**
* This method is invoked when the button is clicked.
- * The method raises 'Command' event to fire up the event handlers.
+ * The method raises 'OnCommand' event to fire up the event handlers.
* If you override this method, be sure to call the parent implementation
* so that the event handlers can be invoked.